@@ -18,8 +18,11 @@ use std::path::PathBuf;
 use std::process::Command;
 use syn::visit::Visit;
 
-use bpf_sys::headers::{get_custom_header_path, get_custom_header_version};
-use bpf_sys::type_gen::get_custom_vmlinux_path;
+use bpf_sys::headers::{
+    available_kernel_header_paths, get_custom_header_path, get_custom_header_version,
+    set_custom_header_path, ENV_SOURCE_PATH, ENV_SOURCE_VERSION,
+};
+use bpf_sys::type_gen::{get_custom_vmlinux_path, ENV_VMLINUX_PATH};
 use cargo_bpf_lib::bindgen as bpf_bindgen;
 use syn::{
     self, parse_str, punctuated::Punctuated, token::Comma, AngleBracketedGenericArguments,
@@ -270,7 +273,17 @@ fn main() {
         .finish();
     tracing::subscriber::set_global_default(subscriber).unwrap();
 
+    if let Ok(_) = env::var("DOCS_RS") {
+        let mut paths = available_kernel_header_paths();
+        paths.sort();
+        if let Some(path) = paths.pop() {
+            set_custom_header_path(path);
+        }
+    }
     rerun_if_changed_dir("include");
+    println!("cargo:rerun-if-env-changed={}", ENV_SOURCE_PATH);
+    println!("cargo:rerun-if-env-changed={}", ENV_SOURCE_VERSION);
+    println!("cargo:rerun-if-env-changed={}", ENV_VMLINUX_PATH);
 
     if get_custom_vmlinux_path().is_some() {
         debug!("Generating bindings with BTF of vmlinux");
